Name:          zfs
Version:       2.2.5
Release:       1mamba
Summary:       An advanced file system and volume manager
Group:         System/Tools
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://zfsonlinux.org
Source:        https://github.com/zfsonlinux/zfs.git/zfs-%{version}/zfs-%{version}.tar.bz2
Patch0:        zfs-2.1.6-only-build-the-module-in-dkms.conf.patch
Patch1:        zfs-2.1.12-dracut-do-not-fail-if-module-is-missing.patch
License:       Common Development and Distribution License
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libaio-devel
BuildRequires: libblkid-devel
BuildRequires: libopenssl-devel
BuildRequires: libpam-devel
BuildRequires: libpython311-devel
BuildRequires: libtirpc-devel
BuildRequires: libudev-devel
BuildRequires: libunwind-devel
BuildRequires: libuuid-devel
BuildRequires: libz-devel
BuildRequires: perl-devel
BuildRequires: python3.11dist(cffi)
## AUTOBUILDREQ-END
Requires:      lib%{name} = %{?epoch:%epoch:}%{version}-%{release}

%description
ZFS is an advanced file system and volume manager which was originally developed for Solaris and is now maintained by the Illumos community.
ZFS on Linux, which is also known as ZoL, is currently feature complete. It includes fully functional and stable SPA, DMU, ZVOL, and ZPL layers.
Full documentation for installing ZoL on your favorite Linux distribution can be found at: http://zfsonlinux.org

%package dkms
Group:         System/Kernel and Hardware/Drivers
Summary:       %{name} kernel module with DKMS build support
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}

%description dkms
This package contains the %{name} kernel module with DKMS build support.

%package -n lib%{name}
Group:         System/Libraries
Summary:       Shared libraries for %{name}

%description -n lib%{name}
This package contains shared libraries for %{name}.

%package -n lib%{name}-devel
Group:         Development/Libraries
Summary:       Development files for %{name}
Requires:      lib%{name} = %{?epoch:%epoch:}%{version}-%{release}

%description -n lib%{name}-devel
This package contains libraries and header files for developing applications that use %{name}.

%package -n python-pyzfs-py3
Group:         System/Libraries
Summary:       Pythonlibraries for %{name}
Requires:      python3
Requires:      python-cffi-py3
Obsoletes:     python-pyzfs-py36 < 2.1.99

%description -n python-pyzfs-py3
This package contains the Python libraries for %{name}.

%debug_package

%prep
%setup -q
%patch 0 -p1 -b .only-build-the-module-in-dkms.conf
%patch 1 -p1
#-D -T
#:<< _EOF
./autogen.sh

%build
#:<< _EOF
%configure \
   --disable-sysvinit \
   --with-config=user \
   --with-systemdunitdir=%{_unitdir} \
   --with-systemdpresetdir=%{_presetdir} \
   --with-udevdir=%{_prefix}/lib/udev \
   --with-udevrulesdir=%{_udevrulesdir} \
   --with-mounthelperdir=%{_sbindir} \
   --with-python=3 \
   PYTHON=%{__python3}

%make

# Create dkms.conf
./scripts/dkms.mkconf -n zfs -v %{version} -f dkms.conf
./scripts/make_gitrev.sh include/zfs_gitrev.h
	
%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%makeinstall \
   bashcompletiondir=%{_datadir}/bash-completion/completions/

# We use dracut not initramfs-tools
rm -rf %{buildroot}%{_datadir}/initramfs-tools

# Install dkms with module source dir
dkmsdir=%{buildroot}%{_prefix}/src/zfs-%{version}
install -d ${dkmsdir}/{config,scripts}
cp -a configure dkms.conf Makefile.in META zfs_config.h.in zfs.release.in include/ module/ ${dkmsdir}/
cp config/compile config/config.* config/missing config/*sh ${dkmsdir}/config/
cp scripts/enum-extract.pl scripts/dkms.postbuild ${dkmsdir}/scripts/
	
%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%post -n lib%{name} -p /sbin/ldconfig
%postun -n lib%{name} -p /sbin/ldconfig

%preun dkms
dkms remove -q -m %{name} -v %{version} --all --rpm_safe_upgrade
:

%posttrans dkms
if [ $1 -ge 1 ]; then
   # clean any legacy alternatives symlink
   dkms remove -q -m %{name} -v %{version} --all --rpm_safe_upgrade
   dkms add -q -m %{name} -v %{version}
   dkms install -q -m %{name} -v %{version}
fi
:

%files
%defattr(-,root,root)
%dir %{_sysconfdir}/zfs
%{_sysconfdir}/zfs/*.example
%dir %{_sysconfdir}/zfs/zed.d
%{_sysconfdir}/zfs/zed.d/zed.rc
%{_sysconfdir}/zfs/zed.d/*.sh
%{_sysconfdir}/sudoers.d/zfs
%dir %{_sysconfdir}/zfs/zpool.d
%{_sysconfdir}/zfs/zfs-functions
%{_sysconfdir}/zfs/zpool.d/*
%config %{_sysconfdir}/default/zfs
%{_bindir}/arcstat
%{_bindir}/arc_summary
%{_bindir}/dbufstat
%{_bindir}/raidz_test
%{_bindir}/zilstat
%{_bindir}/zvol_wait
%{_sbindir}/fsck.zfs
%{_sbindir}/mount.zfs
%{_sbindir}/zdb
%{_sbindir}/zed
%{_sbindir}/zfs
%{_sbindir}/zfs_ids_to_path
%{_sbindir}/zhack
%{_sbindir}/zinject
%{_sbindir}/zpool
%{_sbindir}/zstream
%{_sbindir}/zstreamdump
%{_sbindir}/ztest
%{_sbindir}/zgenhostid
%{_udevrulesdir}/*.rules
%{_prefix}/lib/udev/vdev_id
%{_prefix}/lib/udev/zvol_id
%{_datadir}/pam-configs/zfs_key
%{_presetdir}/50-zfs.preset
%{_unitdir}/zfs-*.service
%{_unitdir}/zfs-*.timer
%{_unitdir}/zfs.target
%{_unitdir}/zfs-volumes.target
%dir %{_datadir}/zfs
%{_datadir}/zfs/*
%{_unitdir}/zfs-import.target
%{_systemdgeneratordir}/zfs-mount-generator
%{_datadir}/bash-completion/completions/zfs
%{_mandir}/man1/arcstat.1.gz
%{_mandir}/man1/raidz_test.1*
%{_mandir}/man1/test-runner.1*
%{_mandir}/man8/zgenhostid.8*
%{_mandir}/man1/zhack.1*
%{_mandir}/man1/ztest.1*
%{_mandir}/man1/zvol_wait.1*
%{_mandir}/man4/spl.4*
%{_mandir}/man4/zfs.4*
%{_mandir}/man5/vdev_id.conf.5*
%{_mandir}/man7/dracut.zfs.7*
%{_mandir}/man7/vdevprops.7*
%{_mandir}/man7/zfsconcepts.7*
%{_mandir}/man7/zfsprops.7*
%{_mandir}/man7/zpool-features.7*
%{_mandir}/man7/zpoolconcepts.7*
%{_mandir}/man7/zpoolprops.7*
%{_mandir}/man8/fsck.zfs.8*
%{_mandir}/man8/mount.zfs.8*
%{_mandir}/man8/vdev_id.8*
%{_mandir}/man8/zdb.8*
%{_mandir}/man8/zed.8*
%{_mandir}/man8/zfs.8*
%{_mandir}/man8/zfs-*.8*
%{_mandir}/man8/zfs_prepare_disk.8*
%{_mandir}/man8/zinject.8*
%{_mandir}/man8/zpool*.8*
%{_mandir}/man8/zstream.8.gz
%{_mandir}/man8/zstreamdump.8*
%{_mandir}/man8/zfs_ids_to_path.8*

%files dkms
%defattr(-,root,root)
%{_prefix}/lib/dracut/modules.d/02zfsexpandknowledge/module-setup.sh
%dir %{_prefix}/lib/dracut/modules.d/90zfs
%{_prefix}/lib/dracut/modules.d/90zfs/*
%{_prefix}/lib/modules-load.d/zfs.conf
%dir %{_prefix}/src/zfs-%{version}
%{_prefix}/src/zfs-%{version}/*

%files -n lib%{name}
%defattr(-,root,root)
%{_libdir}/libnvpair.so.*
%{_libdir}/libuutil.so.*
%{_libdir}/libzfs.so.*
%{_libdir}/libzfsbootenv.so.*
%{_libdir}/libzfs_core.so.*
%{_libdir}/libzpool.so.*
%{_libdir}/security/pam_zfs_key.so
%dir %{_libexecdir}/zfs
%dir %{_libexecdir}/zfs/zed.d
%dir %{_libexecdir}/zfs/zpool.d
%{_libexecdir}/zfs/zfs_prepare_disk
%{_libexecdir}/zfs/zpool_influxdb
%{_libexecdir}/zfs/zpool.d/*
%{_libexecdir}/zfs/zed.d/*.sh
%doc AUTHORS

%files -n lib%{name}-devel
%defattr(-,root,root)
%dir %{_includedir}/libspl
%{_includedir}/libspl/*
%dir %{_includedir}/libzfs
%{_includedir}/libzfs/*
%{_libdir}/libnvpair.a
%{_libdir}/libnvpair.so
%{_libdir}/libuutil.a
%{_libdir}/libuutil.so
%{_libdir}/libzfs.a
%{_libdir}/libzfs.so
%{_libdir}/libzfsbootenv.a
%{_libdir}/libzfsbootenv.so
%{_libdir}/libzfs_core.a
%{_libdir}/libzfs_core.so
%{_libdir}/libzpool.a
%{_libdir}/libzpool.so
%{_libdir}/pkgconfig/libzfs.pc
%{_libdir}/pkgconfig/libzfsbootenv.pc
%{_libdir}/pkgconfig/libzfs_core.pc
#%doc README.markdown

%files -n python-pyzfs-py3
%defattr(-,root,root)
%dir %{python3_sitelib}/libzfs_core
%{python3_sitelib}/libzfs_core/*
%dir %{python3_sitelib}/pyzfs-*-py*.egg-info
%{python3_sitelib}/pyzfs-*-py*.egg-info/*

%changelog
* Wed Aug 07 2024 Automatic Build System <autodist@openmamba.org> 2.2.5-1mamba
- automatic version update by autodist

* Sun May 05 2024 Automatic Build System <autodist@openmamba.org> 2.2.4-1mamba
- automatic version update by autodist

* Fri Feb 23 2024 Automatic Build System <autodist@openmamba.org> 2.2.3-1mamba
- automatic version update by autodist

* Fri Dec 01 2023 Automatic Build System <autodist@mambasoft.it> 2.2.2-1mamba
- automatic version update by autodist

* Tue Nov 28 2023 Automatic Build System <autodist@mambasoft.it> 2.2.1-1mamba
- automatic version update by autodist

* Wed Oct 18 2023 Automatic Build System <autodist@mambasoft.it> 2.2.0-1mamba
- automatic version update by autodist

* Thu Sep 28 2023 Automatic Build System <autodist@mambasoft.it> 2.1.13-1mamba
- automatic version update by autodist

* Thu Jun 08 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.12-2mamba
- zfs-dkms: patch dracut module setup so that dracut won't fail if zfs module does not exist

* Wed Jun 07 2023 Automatic Build System <autodist@mambasoft.it> 2.1.12-1mamba
- automatic version update by autodist

* Sat Apr 22 2023 Automatic Build System <autodist@mambasoft.it> 2.1.11-1mamba
- automatic version update by autodist

* Sat Apr 15 2023 Automatic Build System <autodist@mambasoft.it> 2.1.10-1mamba
- automatic version update by autodist

* Thu Jan 26 2023 Automatic Build System <autodist@mambasoft.it> 2.1.9-1mamba
- automatic version update by autodist

* Sun Jan 22 2023 Automatic Build System <autodist@mambasoft.it> 2.1.8-1mamba
- automatic version update by autodist

* Fri Dec 09 2022 Automatic Build System <autodist@mambasoft.it> 2.1.7-1mamba
- automatic version update by autodist

* Sat Nov 19 2022 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.6-2mamba
- provide dkms subpackage to build module

* Sun Oct 23 2022 Automatic Build System <autodist@mambasoft.it> 2.1.6-1mamba
- automatic version update by autodist

* Tue Jun 28 2022 Automatic Build System <autodist@mambasoft.it> 2.1.5-1mamba
- automatic version update by autodist

* Sat Apr 16 2022 Automatic Build System <autodist@mambasoft.it> 2.1.4-1mamba
- automatic version update by autodist

* Thu Dec 16 2021 Automatic Build System <autodist@mambasoft.it> 2.1.2-1mamba
- automatic version update by autodist

* Sun Oct 17 2021 Automatic Build System <autodist@mambasoft.it> 2.1.1-1mamba
- automatic version update by autodist

* Sat Sep 04 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 2.1.0-1mamba
- update to 2.1.0

* Wed Mar 10 2021 Automatic Build System <autodist@mambasoft.it> 2.0.4-1mamba
- automatic version update by autodist

* Sat Feb 27 2021 Automatic Build System <autodist@mambasoft.it> 2.0.3-1mamba
- automatic version update by autodist

* Sat Jan 30 2021 Automatic Build System <autodist@mambasoft.it> 2.0.1-1mamba
- automatic version update by autodist

* Tue Dec 08 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.5-2mamba
- rebuilt with python3

* Fri Oct 09 2020 Automatic Build System <autodist@mambasoft.it> 0.8.5-1mamba
- automatic version update by autodist

* Wed May 13 2020 Automatic Build System <autodist@mambasoft.it> 0.8.4-1mamba
- automatic version update by autodist

* Sat Feb 01 2020 Automatic Build System <autodist@mambasoft.it> 0.8.3-1mamba
- automatic version update by autodist

* Sat Oct 05 2019 Automatic Build System <autodist@mambasoft.it> 0.8.2-1mamba
- automatic version update by autodist

* Fri Aug 09 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.1-2mamba
- rebuilt with python package

* Sat Aug 03 2019 Automatic Build System <autodist@mambasoft.it> 0.8.1-1mamba
- automatic version update by autodist

* Tue Mar 05 2019 Automatic Build System <autodist@mambasoft.it> 0.7.13-1mamba
- automatic version update by autodist

* Mon Nov 19 2018 Automatic Build System <autodist@mambasoft.it> 0.7.12-1mamba
- automatic version update by autodist

* Sat Nov 03 2018 Automatic Build System <autodist@mambasoft.it> 0.7.11-1mamba
- automatic version update by autodist

* Fri May 25 2018 Automatic Build System <autodist@mambasoft.it> 0.7.9-1mamba
- automatic version update by autodist

* Fri Apr 13 2018 Automatic Build System <autodist@mambasoft.it> 0.7.8-1mamba
- automatic version update by autodist

* Fri Mar 30 2018 Automatic Build System <autodist@mambasoft.it> 0.7.7-1mamba
- automatic version update by autodist

* Mon Oct 17 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 0.6.5.8-1mamba
- update to 0.6.5.8

* Sat May 14 2016 Automatic Build System <autodist@mambasoft.it> 0.6.5.7-1mamba
- automatic version update by autodist

* Thu Mar 24 2016 Automatic Build System <autodist@mambasoft.it> 0.6.5.6-1mamba
- automatic version update by autodist

* Fri Jun 05 2015 Automatic Build System <autodist@mambasoft.it> 0.6.4.1-1mamba
- automatic version update by autodist

* Sat Oct 04 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 0.6.3-1mamba
- package created using the webbuild interface
